@@ -7,7 +7,7 @@ use MouseX::Types;
 
 BEGIN {
     my $builtin_type = +{ map { $_ => $_ } Mouse::Util::TypeConstraints->list_all_builtin_type_constraints };
-    sub type_storage { $builtin_type }
+    sub type_storage { $builtin_type }  ## no critic
 }
 
 1;
